pub struct ParallelConfig { /* private fields */ }Expand description
Parallel build configuration.
Implementations
Sourceimpl ParallelConfig
impl ParallelConfig
Sourcepub fn with_percentage(self, percentage: f32) -> Self
pub fn with_percentage(self, percentage: f32) -> Self
Set the percentage of available threads to use (clamped to 0.0..=1.0).
Sourcepub fn with_max_threads(self, max: usize) -> Self
pub fn with_max_threads(self, max: usize) -> Self
Set the maximum number of threads.
Sourcepub fn with_min_threads(self, min: usize) -> Self
pub fn with_min_threads(self, min: usize) -> Self
Set the minimum number of threads.
Sourcepub fn with_nvcc_thread_patterns<S: AsRef<str>>(
self,
patterns: &[S],
num_nvcc_threads: usize,
) -> Self
pub fn with_nvcc_thread_patterns<S: AsRef<str>>( self, patterns: &[S], num_nvcc_threads: usize, ) -> Self
Set patterns for files that should use nvcc’s internal --threads=N flag.
Replaces the default patterns ("flash_api", "cutlass").
Sourcepub fn should_use_nvcc_threads(&self, path_str: &str) -> bool
pub fn should_use_nvcc_threads(&self, path_str: &str) -> bool
Check if a file matches any of the thread patterns.
Supports glob patterns (e.g. "gemm_*.cu") and substring matching.
Sourcepub fn thread_count(&self) -> usize
pub fn thread_count(&self) -> usize
Calculate the number of threads to use.
Sourcepub fn init_thread_pool(&self) -> Result<(), ThreadPoolBuildError>
pub fn init_thread_pool(&self) -> Result<(), ThreadPoolBuildError>
Initialize the rayon thread pool with configured settings.
Sourcepub fn nvcc_threads(&self) -> Option<usize>
pub fn nvcc_threads(&self) -> Option<usize>
Get thread count for nvcc’s --threads argument.